==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Elolvastam a licensz megállapodást és elfogadtam"

, "License Agreement"
: "Licensz megállapodás"

, "I have read the privacy agreement and accept it"
: "Elolvastam a titoktartási megállapodást és elfogadtam"

, "Privacy Agreement"
: "Titoktartási megállapodás"

, "Accept Terms and Conditions"
: "Kikötések és feltételek elfogadása"

, "Backend"
: "Háttér"

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Gépnév"

, "Username"
: "Felhasználónév"

, "Password"
: "Jelszó"

, "Port"
: "Port"

, "Secure Connection"
: "Biztonságos kapcsolat"

, "None"
: "Semmi"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Rendszer azonosító használata"

, "No"
: "Nem"

, "Yes"
: "Igen"

, "Append domain to login name"
: "Domain csatolása a felhasználónévhez"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin jelszó"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Azonosítás"

, "Login"
: "Felhasználónév"

, "Plain"
: "Egyszerű"

, "Primary Domain"
: "Elsődleges Domain"

, "Secondary Domains (comma separated)"
: "Másodlagos Domainek (vesszővel elválasztva)"

, "Notifications service address"
: "Értesítési szolgáltatás címe"

, "Notification Username"
: "Értesítés felhasználóneve"

, "Notification Password"
: "Értesítés jelszava"

, "Notifications local client (hostname or IP address)"
: "Helyi kliens értesítések (hosztnév vagy IP cím)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql gépnév"

, "MySql Database"
: "MySql adatbázis"

, "MySql User"
: "MySql felhasználónév"

, "MySql Password"
: "MySql jelszó"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Felhasználónév vagy UID"

, "Group or GID"
: "Csoport vagy GID"

, "Home Template"
: "Home sablon"

, "Password Scheme"
: "Jelszó séma"

, "PLAIN-MD5"
: "Alap-MD5"

, "MD5-CRYPT"
: "MD5-Kódolt"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "Egyszerű"

, "Terms and Conditions"
: "Kikötések és feltételek"

, "Setup Checks"
: "Telepítési ellenörzések"

, "Config Manager"
: "Beállítások kezelése"

, "Authentication/Accounts"
: "Azonosítás/Belépések"

, "Email"
: "Email"

, "Application Manager"
: "Programok kezelése"

, "Setup"
: ""

, "Name"
: "Név"

, "Enabled"
: "Engedélyezett"

, "Order"
: "Sorrend"

, "Installed Version"
: "Telepített verzió"

, "Available Version"
: "Elérhető verzió"

, "Status"
: "Állapot"

, "Depends on"
: "Függőségek"

, "Install application"
: "Program telepítése"

, "Uninstall application"
: "Program eltávolítása"

, "Update application"
: "Program frissítése"

, "Go to {0} login"
: "{0} bejelentkezéshez ugrás"

, "uninstall"
: "eltávolítás"

, "Do you really want to uninstall the application(s)?"
: "Biztosan el szeretnéd távolítani a programo(ka)t?"

, "This may take a while"
: "Ez eltarthat egy ideig"

, "Dependency Violation"
: "Függőségek megszegése"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Minden meglévő csoport és felhasználó törlése"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "SQL-ről LDAP-ra váltás törölni fogja az összes meglévő Felhasználói fiókokat, Csoportokat és Szabályokat. Biztosan szeretnéd váltani az azonsítók tárolási hátterét LDAP-ra?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Kezdő Admin felhasználó"

, "Initial admin login name"
: "Kezdő Admin felhasználónév"

, "Initial admin Password"
: "Kezdő Admin jelszó"

, "Password confirmation"
: "Jelszó megerősítés"

, "Authentication provider"
: "Azonsítási szolgáltató"

, "Try to split username"
: "Próbáld kettéválasztani a felhasználónevet"

, "Account canonical form"
: "Azonosító kanonikus forma"

, "Account domain name"
: ""

, "Account domain short name"
: "Azonosító rövid domain név"

, "Host"
: "Gép"

, "Login name"
: "Felhasználó név"

, "Bind requires DN"
: "Bindnek szükséges a DN"

, "Start TLS"
: ""

, "Base DN"
: "Alap DN"

, "Search filter"
: "Keresési szűrő"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Azonsítók tárolása"

, "Default user group name"
: "Alapértelmezett felhasználói csoport neve"

, "Default admin group name"
: "Alapértelmezett admin csoport neve"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Jelszó beállítások"

, "User can change password"
: "Felhasználó változtathat jelszót"

, "Enable password policy"
: "Jelszó szabályok engedélyezése"

, "Only ASCII"
: "Csak ASCII"

, "Minimum length"
: "Minimum hossz"

, "Minimum word chars"
: "Minimum betű karakterek"

, "Minimum uppercase chars"
: "Minimum nagy karakterek"

, "Minimum special chars"
: "Minimum speciális karakterek"

, "Minimum numbers"
: "Minimum számok"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Átirányítási beállítások"

, "Redirect Url (redirect to login screen if empty)"
: "Átirányítási URL (átirányítás a belépő oldalra ha üres)"

, "Redirect Always (if No, only redirect after logout)"
: "Átirányítás mindig (ha Nem, átirányítás csak kilépés után)"

, "Redirect to referring site, if exists"
: "Átirányítás a hivatkozó oldalra, ha létezik"

, "Password encoding"
: "Jelszó kódolás"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Felhasználó DN"

, "User Filter"
: "Felhasználó szűrő"

, "User Search Scope"
: "Felhasználó keresési kör"

, "Groups DN"
: "Csoportok DN"

, "Group Filter"
: "Csoport szűrő"

, "Group Search Scope"
: "Csoport keresési kör"

, "Use Rfc 2307 bis"
: "RFC 2307 használata"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Min felhasználó Id"

, "Max User Id"
: "Max felhasználó Id"

, "Min Group Id"
: "Min csoport Id"

, "Max Group Id"
: "Max csoport Id"

, "Group UUID Attribute name"
: "Csoport UUID tulajdonság név"

, "User UUID Attribute name"
: "Felhasználó UUID tulajdonság név"

, "Readonly access"
: "Csak olvasható elérés"

, "Save config and install"
: "Beállítás elmentése és telepítés"

, "Save config"
: "Beállítás elmentése"

, "Passwords don't match"
: "Jelszó nem egyezik"

, "Should not be empty"
: "Nem lehet üres"

, "Performing Environment Checks..."
: "Környezeti ellenörzés végrehajtása..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Nem található semmi {0}. Kérlek próbáld megváltoztatni a szűrő feltételeket, a nézet opciókat vagy a {1} amiben keresel."

, "Check"
: "Ellenörzés"

, "Result"
: "Eredmény"

, "Error"
: "Hiba"

, "Run setup tests"
: "Telepítési tesztek futtatása"

, "Ignore setup tests"
: "Telepítési tesztek figyelmen kívül hagyása"

, "Application, Applications"
: [
  "Program"
 ,"Programok"

]
, "File"
: "File"

, "Setup Authentication"
: "Telepítési azonosítás"

, "Database"
: "Adatbázis"

, "User"
: "Felhasználó"

, "Prefix"
: "Előképző"

, "Logging"
: "Naplózás"

, "Filename"
: "Filenév"

, "Priority"
: "Prioritás"

, "Caching"
: "Gyorsítótárazás"

, "Lifetime (seconds)"
: "Élettartam (másodperc)"

, "Path"
: "Elérési út"

, "Queue"
: ""

, "Session"
: "Munkafázis"

, "Temporary files"
: "Ideiglenes fileok"

, "Temporary Files Path"
: "Ideiglenes filok elérési útja"

, "Filestore directory"
: "Filetárolási könyvtár"

, "Filestore Path"
: "Filetárolás elérési útja"

, "Addressbook Map panel"
: "Címjegyzék Térkép fül"

, "Map panel"
: "Térkép fül"

, "disabled"
: "letiltva"

, "enabled"
: "engedélyezve"

, "Config file is not writable"
: "Beállítási file nem írható"

, "Download config file"
: "Beállítási file letöltése"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Program"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Környezeti ellenörzés végrehajtása..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Nem található semmi {0}. Kérlek próbáld megváltoztatni a szűrő feltételeket, a nézet opciókat vagy a {1} amiben keresel."

, "Check"
: "Ellenörzés"

, "Result"
: "Eredmény"

, "Message"
: ""

, "Run setup tests"
: "Telepítési tesztek futtatása"

, "Ignore setup tests"
: "Telepítési tesztek figyelmen kívül hagyása"

, "Install application"
: "Program telepítése"

, "Name"
: "Név"

, "Enabled"
: "Engedélyezett"

, "Order"
: "Sorrend"

, "Installed Version"
: "Telepített verzió"

, "Available Version"
: "Elérhető verzió"

, "Status"
: "Állapot"

, "Depends on"
: "Függőségek"

, "Uninstall application"
: "Program eltávolítása"

, "Update applications"
: ""

, "Go to {0} login"
: "{0} bejelentkezéshez ugrás"

, "uninstall"
: "eltávolítás"

, "Do you really want to uninstall the application(s)?"
: "Biztosan el szeretnéd távolítani a programo(ka)t?"

, "This may take a while"
: "Ez eltarthat egy ideig"

, "Dependency Violation"
: "Függőségek megszegése"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Minden meglévő csoport és felhasználó törlése"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "SQL-ről LDAP-ra váltás törölni fogja az összes meglévő Felhasználói fiókokat, Csoportokat és Szabályokat. Biztosan szeretnéd váltani az azonsítók tárolási hátterét LDAP-ra?"

, "Backend"
: "Háttér"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Kezdő Admin felhasználó"

, "Initial admin login name"
: "Kezdő Admin felhasználónév"

, "Initial admin Password"
: "Kezdő Admin jelszó"

, "Password confirmation"
: "Jelszó megerősítés"

, "Authentication provider"
: "Azonsítási szolgáltató"

, "Try to split username"
: "Próbáld kettéválasztani a felhasználónevet"

, "Yes"
: "Igen"

, "No"
: "Nem"

, "Account canonical form"
: "Azonosító kanonikus forma"

, "Account domain name"
: ""

, "Account domain short name"
: "Azonosító rövid domain név"

, "Host"
: "Gép"

, "Login name"
: "Felhasználó név"

, "Password"
: "Jelszó"

, "Bind requires DN"
: "Bindnek szükséges a DN"

, "Start TLS"
: ""

, "SSL"
: "SSL"

, "Port"
: "Port"

, "Base DN"
: "Alap DN"

, "Search filter"
: "Keresési szűrő"

, "Hostname"
: "Gépnév"

, "Secure Connection"
: "Biztonságos kapcsolat"

, "None"
: "Semmi"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Domain csatolása a felhasználónévhez"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Azonsítók tárolása"

, "Default user group name"
: "Alapértelmezett felhasználói csoport neve"

, "Default admin group name"
: "Alapértelmezett admin csoport neve"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Jelszó beállítások"

, "User can change password"
: "Felhasználó változtathat jelszót"

, "Enable password policy"
: "Jelszó szabályok engedélyezése"

, "Only ASCII"
: "Csak ASCII"

, "Minimum length"
: "Minimum hossz"

, "Minimum word chars"
: "Minimum betű karakterek"

, "Minimum uppercase chars"
: "Minimum nagy karakterek"

, "Minimum special chars"
: "Minimum speciális karakterek"

, "Minimum numbers"
: "Minimum számok"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Átirányítási beállítások"

, "Redirect Url (redirect to login screen if empty)"
: "Átirányítási URL (átirányítás a belépő oldalra ha üres)"

, "Redirect Always (if No, only redirect after logout)"
: "Átirányítás mindig (ha Nem, átirányítás csak kilépés után)"

, "Redirect to referring site, if exists"
: "Átirányítás a hivatkozó oldalra, ha létezik"

, "Password encoding"
: "Jelszó kódolás"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Felhasználó DN"

, "User Filter"
: "Felhasználó szűrő"

, "User Search Scope"
: "Felhasználó keresési kör"

, "Groups DN"
: "Csoportok DN"

, "Group Filter"
: "Csoport szűrő"

, "Group Search Scope"
: "Csoport keresési kör"

, "Use Rfc 2307 bis"
: "RFC 2307 használata"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Min felhasználó Id"

, "Max User Id"
: "Max felhasználó Id"

, "Min Group Id"
: "Min csoport Id"

, "Max Group Id"
: "Max csoport Id"

, "Group UUID Attribute name"
: "Csoport UUID tulajdonság név"

, "User UUID Attribute name"
: "Felhasználó UUID tulajdonság név"

, "Readonly access"
: "Csak olvasható elérés"

, "Save config and install"
: "Beállítás elmentése és telepítés"

, "Save config"
: "Beállítás elmentése"

, "Passwords don't match"
: "Jelszó nem egyezik"

, "Should not be empty"
: "Nem lehet üres"

, "File"
: "File"

, "Setup Authentication"
: "Telepítési azonosítás"

, "Username"
: "Felhasználónév"

, "Database"
: "Adatbázis"

, "User"
: "Felhasználó"

, "Prefix"
: "Előképző"

, "Logging"
: "Naplózás"

, "Filename"
: "Filenév"

, "Priority"
: "Prioritás"

, "Caching"
: "Gyorsítótárazás"

, "Lifetime (seconds)"
: "Élettartam (másodperc)"

, "Path"
: "Elérési út"

, "Queue"
: ""

, "Session"
: "Munkafázis"

, "Temporary files"
: "Ideiglenes fileok"

, "Temporary Files Path"
: "Ideiglenes filok elérési útja"

, "Filestore directory"
: "Filetárolási könyvtár"

, "Filestore Path"
: "Filetárolás elérési útja"

, "Addressbook Map panel"
: "Címjegyzék Térkép fül"

, "Map panel"
: "Térkép fül"

, "disabled"
: "letiltva"

, "enabled"
: "engedélyezve"

, "Config file is not writable"
: "Beállítási file nem írható"

, "Download config file"
: "Beállítási file letöltése"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Rendszer azonosító használata"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin jelszó"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Azonosítás"

, "Login"
: "Felhasználónév"

, "Plain"
: "Egyszerű"

, "Primary Domain"
: "Elsődleges Domain"

, "Secondary Domains (comma separated)"
: "Másodlagos Domainek (vesszővel elválasztva)"

, "Notifications service address"
: "Értesítési szolgáltatás címe"

, "Notification Username"
: "Értesítés felhasználóneve"

, "Notification Password"
: "Értesítés jelszava"

, "Notifications local client (hostname or IP address)"
: "Helyi kliens értesítések (hosztnév vagy IP cím)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql gépnév"

, "MySql Database"
: "MySql adatbázis"

, "MySql User"
: "MySql felhasználónév"

, "MySql Password"
: "MySql jelszó"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Felhasználónév vagy UID"

, "Group or GID"
: "Csoport vagy GID"

, "Home Template"
: "Home sablon"

, "Password Scheme"
: "Jelszó séma"

, "PLAIN-MD5"
: "Alap-MD5"

, "MD5-CRYPT"
: "MD5-Kódolt"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "Egyszerű"

, "Setup"
: ""

, "Application, Applications"
: [
  "Program"
 ,"Programok"

]
, "Terms and Conditions"
: "Kikötések és feltételek"

, "Setup Checks"
: "Telepítési ellenörzések"

, "Config Manager"
: "Beállítások kezelése"

, "Authentication/Accounts"
: "Azonosítás/Belépések"

, "Email"
: "Email"

, "Application Manager"
: "Programok kezelése"

, "I have read the license agreement and accept it"
: "Elolvastam a licensz megállapodást és elfogadtam"

, "License Agreement"
: "Licensz megállapodás"

, "I have read the privacy agreement and accept it"
: "Elolvastam a titoktartási megállapodást és elfogadtam"

, "Privacy Agreement"
: "Titoktartási megállapodás"

, "Accept Terms and Conditions"
: "Kikötések és feltételek elfogadása"


, "Application"
: "Program"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
